from flytekit import ImageSpec, task, workflow

image = ImageSpec(
    builder="fast-builder",
    # builder="envd",
    packages=["numpy"],
    registry="localhost:30000",
    env={"ABC": "CDE"},
)


@task(container_image=image)
def my_task() -> int:
    import numpy as np

    X = np.asarray([1, 2, 3])
    return int(X[1])


@workflow
def wf() -> int:
    return my_task()



from flytekit import ImageSpec
from imagespec_fast_builder import FastImageBuilder

image_spec = ImageSpec(
    name="flyte_playground",
    builder="fast-builder",
    packages=["torch==2.2.2"],
    registry="ghcr.io/thomasjpfan",
    # platform="linux/arm64",
    cuda="12.3.2",
    cudnn="8",
)

FastImageBuilder()._build_image(image_spec, push=False)



from flytekit import ImageSpec

from imagespec_fast_builder import FastImageBuilder
from flytekit.image_spec.image_spec import ImageBuildEngine

folding_img = ImageSpec(
    name="unionbio-protein",
    python_version="3.11",
    conda_channels=["bioconda", "conda-forge"],
    conda_packages=["prodigal", "biotite", "biopython", "py3Dmol"],
    registry="ghcr.io/unionai-oss",
    platform="linux/amd64",
)
# Generic way to build an image, if registry is set, then the image is automatically pushed
# ImageBuildEngine().build(image_spec)

# My image builder has a private not push command
FastImageBuilder()._build_image(folding_img, push=False)
